@@ -1,11 +1,13 @@
-package Thread::Queue::Monitored;
+use 5.014;
+#package Thread::Queue::Monitored 1.00; # not supported by PAUSE or MetaCPAN :-(
+package Thread::Queue::Monitored;       # please remove if no longer needed
 
 # initializations
-@ISA= qw(Thread::Queue);
-$VERSION= '0.14';
+our @ISA= qw( Thread::Queue );
+our $VERSION= '1.00';                   # please remove if no longer needed
 
-# be as strict as possible
-use strict;
+# be as verbose as possible
+use warnings;
 
 # modules that we need
 use Thread::Queue (); # no need to pollute namespace
@@ -182,21 +184,14 @@ sub _monitor {
             lock( @{$queue} );
             threads::shared::cond_wait @{$queue} until @{$queue};
             @value= @{$queue};
-            @{$queue} = ();
+            @{$queue}= ();
         }
 
         # process all values
         foreach (@value) {
 
-            # done, was we've seen the exit value
-            if ( defined($exit) ) {
-                return $post->(@_) if $_ eq $exit;
-            }
-
-            # no value, so we're done
-            elsif( !defined($_) ) {
-                return $post->(@_);
-            }
+            # done, we've seen the exit value
+            return $post->(@_) when $exit;
 
             # perform the monitoring for this value
             $monitor->($_);
@@ -215,7 +210,7 @@ Thread::Queue::Monitored - monitor a queue for specific content
 =head1 SYNOPSIS
 
     use Thread::Queue::Monitored;
-    my ($q,$t) = Thread::Queue::Monitored->new( {
+    my ( $q, $t)= Thread::Queue::Monitored->new( {
       monitor => sub { print "monitoring value $_[0]\n" }, # is a must
       pre     => sub { print "prepare monitoring\n" },     # optional
       post    => sub { print "stop monitoring\n" },        # optional
@@ -233,18 +228,14 @@ Thread::Queue::Monitored - monitor a queue for specific content
 
 =head1 VERSION
 
-This documentation describes version 0.14.
+This documentation describes version 1.00.
 
 =head1 DESCRIPTION
 
                     *** A note of CAUTION ***
 
- This module only functions on threaded perl or an unthreaded perl
- with the "forks" module installed.
-
- Please also note that this documentation describes the "maint" version
- of this code.  This version is essentially frozen.  Please use a 5.14
- version of perl for the "blead" version of this code.
+ This module only functions if threading has been enabled when building
+ Perl, or if the "forks" module has been installed on an unthreaded Perl.
 
                     *************************
 
@@ -275,7 +266,6 @@ Any number of threads can safely add elements to the end of the list.
    exit    => 'exit', # default to undef
  } );
 
-
 The C<new> function creates a monitoring function on an existing or on an new
 (empty) queue.  It returns the instantiated Thread::Queue::Monitored object
 in scalar context: in that case, the monitoring thread will be detached and
@@ -414,12 +404,13 @@ queue.  The queue will grow as needed to accommodate the list.  If the
 
 =head1 REQUIRED MODULES
 
+ Test::More (0.88)
  Thread::Queue (any)
 
 =head1 CAVEATS
 
 You cannot remove any values from the queue, as that is done by the monitoring
-thread.  Therefore, the methods "dequeue", "dequeue_dontwait" and
+thread.  Therefore, the methods "dequeue", "dequeue_dontwait", "dequeue_nb" and
 "dequeue_keep" are disabled on this object.
 
 =head1 AUTHOR
